---
toc: false
title: Documentation For Developers
---

If you're planning on working on the `fastai` library source code and/or documentation, please make sure to familiarize yourself with the following documents. Note: if you're simply using the library, rather than wanting to modify it, you should refer instead to [docs.fast.ai](https://docs.fast.ai).

* [Troubleshooting](troubleshoot.md)
* [Notes for developers](develop.md)
* [Writing and running tests](test.md)
* [GPU Notes](gpu.md)
* [git notes](git.md)
* [Making a release](release.md)
* [Abbreviation guide](abbr.md)
* [Style guide](style.md)
* [Documentation maintenance](https://docs.fast.ai/gen_doc.html)
